# velocity_rest_client

Velocity is python ReST client for Velocity ReST API that contains handy functions. 

This ReST client supports python2.7.16+ and python3+

## Contact
feel free to contact for any issue while using the restclient
poornima.wari@spirent.com
support@spirent.com

## License
[MIT]
